.. _acronyms:

List of Acronyms
=================

.. glossary::

    ACN
      Alternating Column Noise.

    ADC
      Analog-to-Digital Converter.

    APD
      Avalanche Photo Diode.

    CCD
      Charge-Coupled Device.

    CDM
      Charge Distortion Model.

    CIS
      Contact Imaging Sensor.

    CMOS
      Complementary Metal Oxide Semiconductor.

    CTI
      Charge Transfer Inefficiency.

    DAC
      Digital-to-Analog Converter.

    ESO
      European South Observatory.

    HDF5
      Hierarchical Data Format.

    LSB
      Least Significant Bit.

    MCT
      Mercury Cadmium Telluride (HgCdTe).

    MKID
        Microwave Kinetic-Inductance Detector.

    MSB
      Most Significant Bit.

    PSF
      Point Spread Function.

    QE
      Quantum Efficiency.

    SAR
      Successive Approximation Register.
